==> haskell-constraints-0.9.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: constraints
version: 0.9.1
id: constraints-0.9.1-4sh8KFItdKjFIEFwHyUnLD
key: constraints-0.9.1-4sh8KFItdKjFIEFwHyUnLD
license: BSD2
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/constraints/
synopsis: Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.
    .
    This package provides a vocabulary for working with them.
category: Constraints
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Unsafe Data.Constraint.Nat
    Data.Constraint.Symbol
abi: bb47ce874e2dc734fa092439bb27f280
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/constraints-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/constraints-0.9.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/constraints-0.9.1
hs-libraries: HSconstraints-0.9.1-4sh8KFItdKjFIEFwHyUnLD
depends:
    base-4.9.0.0 binary-0.8.3.0 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html: /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-0.9.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: constraints
version: 0.9.1
id: constraints-0.9.1-GeSkpqRm6PxGwPkxjMsr1O
key: constraints-0.9.1-GeSkpqRm6PxGwPkxjMsr1O
license: BSD2
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/constraints/
synopsis: Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.
    .
    This package provides a vocabulary for working with them.
category: Constraints
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Unsafe Data.Constraint.Nat
    Data.Constraint.Symbol
abi: fed440fef1e38f5d4d7d18300427feea
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/constraints-0.9.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/constraints-0.9.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/constraints-0.9.1
hs-libraries: HSconstraints-0.9.1-GeSkpqRm6PxGwPkxjMsr1O
depends:
    base-4.9.1.0 binary-0.8.3.0 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    hashable-1.2.6.0-3tyIJq2bWc6AwvrDmNvwy7
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
haddock-interfaces: /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html: /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
